Juan Lang : shlwapi: Small cleanups.

Alexandre Julliard julliard at wine.codeweavers.com
Tue Jun 20 16:03:52 CDT 2006


Module: wine
Branch: refs/heads/master
Commit: 8076d1cf12ced624af191542801f7b26706f25f9
URL:    http://source.winehq.org/git/?p=wine.git;a=commit;h=8076d1cf12ced624af191542801f7b26706f25f9

Author: Juan Lang <juan_lang at yahoo.com>
Date:   Tue Jun 20 08:23:12 2006 -0700

shlwapi: Small cleanups.

- forward MLGetUILanguage to kernel32
- correct type of parameter to MLLoadLibrary

---

 dlls/shlwapi/ordinal.c    |   26 +++++++-------------------
 dlls/shlwapi/shlwapi.spec |    2 +-
 2 files changed, 8 insertions(+), 20 deletions(-)

diff --git a/dlls/shlwapi/shlwapi.spec b/dlls/shlwapi/shlwapi.spec
index e7a9d9f..0295e1b 100644
--- a/dlls/shlwapi/shlwapi.spec
+++ b/dlls/shlwapi/shlwapi.spec
@@ -373,7 +373,7 @@
 373 stdcall -noname DdeQueryStringWrapW(long ptr wstr long long) user32.DdeQueryStringW
 374 stub -noname SHCheckDiskForMediaA
 375 stub -noname SHCheckDiskForMediaW
-376 stdcall -noname MLGetUILanguage()  # kernel32.GetUserDefaultUILanguage
+376 stdcall -noname MLGetUILanguage() kernel32.GetUserDefaultUILanguage
 377 stdcall MLLoadLibraryA(str long long)
 378 stdcall MLLoadLibraryW(wstr long long)
 379 stub -noname Shell_GetCachedImageIndexWrapW




More information about the wine-cvs mailing list
diff --git a/dlls/shlwapi/ordinal.c b/dlls/shlwapi/ordinal.c
index af5950e..669cff0 100644
--- a/dlls/shlwapi/ordinal.c
+++ b/dlls/shlwapi/ordinal.c
@@ -3394,32 +3394,20 @@ HICON WINAPI ExtractIconWrapW(HINSTANCE 
 }
 
 /*************************************************************************
- *      @	[SHLWAPI.376]
- */
-LANGID WINAPI MLGetUILanguage(void)
-{
-    FIXME("() stub\n");
-    /* FIXME: This should be a forward in the .spec file to the win2k function
-     * kernel32.GetUserDefaultUILanguage, however that function isn't there yet.
-     */
-    return GetUserDefaultLangID();
-}
-
-/*************************************************************************
  *      @	[SHLWAPI.377]
  *
  * Load a library from the directory of a particular process.
  *
  * PARAMS
  *  new_mod   [I] Library name
  *  inst_hwnd [I] Module whose directory is to be used
  *  dwFlags   [I] Flags controlling the load
  *
  * RETURNS
  *  Success: A handle to the loaded module
  *  Failure: A NULL handle.
  */
-HMODULE WINAPI MLLoadLibraryA(LPCSTR new_mod, HMODULE inst_hwnd, DWORD dwFlags)
+HMODULE WINAPI MLLoadLibraryA(LPCSTR new_mod, HMODULE inst_hwnd, BOOL bCrossCodePage)
 {
   /* FIXME: Native appears to do DPA_Create and a DPA_InsertPtr for
    *        each call here.
@@ -3443,7 +3431,7 @@ HMODULE WINAPI MLLoadLibraryA(LPCSTR new
     LPSTR ptr;
     DWORD len;
 
-    FIXME("(%s,%p,0x%08lx) semi-stub!\n", debugstr_a(new_mod), inst_hwnd, dwFlags);
+    FIXME("(%s,%p,%d) semi-stub!\n", debugstr_a(new_mod), inst_hwnd, bCrossCodePage);
     len = GetModuleFileNameA(inst_hwnd, mod_path, sizeof(mod_path));
     if (!len || len >= sizeof(mod_path)) return NULL;
 
@@ -3461,13 +3449,13 @@ HMODULE WINAPI MLLoadLibraryA(LPCSTR new
  *
  * Unicode version of MLLoadLibraryA.
  */
-HMODULE WINAPI MLLoadLibraryW(LPCWSTR new_mod, HMODULE inst_hwnd, DWORD dwFlags)
+HMODULE WINAPI MLLoadLibraryW(LPCWSTR new_mod, HMODULE inst_hwnd, BOOL bCrossCodePage)
 {
     WCHAR mod_path[2*MAX_PATH];
     LPWSTR ptr;
     DWORD len;
 
-    FIXME("(%s,%p,0x%08lx) semi-stub!\n", debugstr_w(new_mod), inst_hwnd, dwFlags);
+    FIXME("(%s,%p,%d) semi-stub!\n", debugstr_w(new_mod), inst_hwnd, bCrossCodePage);
     len = GetModuleFileNameW(inst_hwnd, mod_path, sizeof(mod_path) / sizeof(WCHAR));
     if (!len || len >= sizeof(mod_path) / sizeof(WCHAR)) return NULL;
 
@@ -3394,32 +3394,20 @@ HICON WINAPI ExtractIconWrapW(HINSTANCE 
  *
  * PARAMS
- *  new_mod   [I] Library name
- *  inst_hwnd [I] Module whose directory is to be used
- *  dwFlags   [I] Flags controlling the load
+ *  new_mod        [I] Library name
+ *  inst_hwnd      [I] Module whose directory is to be used
+ *  bCrossCodePage [I] Should be FALSE (currently ignored)
  *
  * RETURNS